function v = learnV2Pubfig(w,C,O,S,oldV)
load('hist_vertical_withoutNaN.mat');
hp=hh;
clear hh;
X_=hp;
% 'w' : the learned parameter-vector (ldx1 dimension) using rsvm
% 'C' : is the trade-off parameter
% 'X_' : an n x d matrix, where d is feature dimension
% 'O' : an p x m matrix, where m is no. of samples and 
%       p is no. of ordered pairs
% 'S' : an q x m matrix, where q is no. of similar pairs
%   
% Assumption : no. of blocks per image = n/m = l
%


numOfSamples = size(O,2);
numOfBlocks = size(X_,1)/numOfSamples;
ftrDim = size(X_,2);

maxIter = 10000;
epsilon = 10^(-12);

v = oldV;
v = v/sum(v);


% save feature-scores corresponding to each sample 
% in a matrix
w = reshape(w,[ftrDim,numOfBlocks]);
X = zeros(numOfSamples,numOfBlocks);
for i = 1:numOfSamples
	startIndx = (i-1)*numOfBlocks + 1;
	endIndx = i*numOfBlocks;
	count = 0;
	for j = startIndx:endIndx
		count = count + 1;
		X(i,count) = X_(j,:)*w(:,count);
	end;
end;
clear X_;


% compute initial error (value of minimization function)
OXv = (max(0,-O*X*v+1)).^2 ;
SXv = (abs(S*X*v)).^2;
currErr = C * (sum(OXv) + sum(SXv));
% disp(['Initial error = ' num2str(currErr)]);


% set initial learning-rate
eta = 1;
tempErr = currErr;
while( tempErr>0.0001 )
	tempErr = tempErr/10;
	eta = eta/10;
end;

% learn 'v'
prevErr = currErr;
prevV = v;
tic;
for iter = 1:maxIter
	flag = 0;

	% compute gradient
	part1 = (2*(max(0,-O*X*v+1))'*(-O*X))';
	part2 = (2*(S*X*v)'*(S*X))';
	delJ = C * (part1+part2);
		
	% compute new 'v' and re-project
	v = v - eta*delJ;
	v(v<0) = min(v(v>=0))/1000;
	v = v/sum(v);
	
	diffV = v-prevV;
	if( diffV'*diffV < epsilon )
		flag = 1;
	end;
		
	% re-compute error
	OXv = (max(0,-O*X*v+1)).^2 ;
	SXv = (abs(S*X*v)).^2;
	currErr = C * (sum(OXv) + sum(SXv));
	
% 	disp([num2str(iter) ' -- ' num2str(currErr)]);
	
	% update 'v' and learning-rate
	if( currErr < prevErr )
		prevErr = currErr;
		prevV = v;
		eta = eta*1.02;
	else
		v = prevV;
		eta = eta/2;
	end;



	% breaking conditions
	if( eta <= 10^(-26) )
		break;
	end;
	if( flag==1 )
		break;
	end;
end;
toc;

v = v/sum(v);


